==> pogamut-emohawk-ville-3.5.2-20130819.040119-107-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/item/ingredient/AbstractSolidIngredientSliceMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.observationMemory.memorization.item.AbstractCountableItemMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.item.ingredient.AbstractSolidIngredientSliceReplication;

/** Abstract solid ingredient slice memorization
 */
public class AbstractSolidIngredientSliceMemorization
	<MemorizedClass extends AbstractSolidIngredientSliceReplication>
	extends AbstractCountableItemMemorization<MemorizedClass> 
	implements IBrothableIngredientMemorization<MemorizedClass>, ICharrableIngredientMemorization<MemorizedClass>, IBoilableIngredientMemorization<MemorizedClass> {
	
	protected float boiledness, charredness, brothStrengthPotential, volume;
	
	public AbstractSolidIngredientSliceMemorization(
		MemorizedClass object, 
		ObservationMemory observationMemory,
		IDeferredConstructorChainer deferredConstructorChainer
	) {
		super( object, observationMemory, deferredConstructorChainer );
		boiledness = object.getBoiledness();
		charredness = object.getCharredness();
		brothStrengthPotential = object.getBrothStrengthPotential();
		volume = object.getVolume();
	}

	@Override
	public float getBoiledness() {
		return boiledness;
	}
	
	@Override
	public float getCharredness() {
		return charredness;
	}

	@Override
	public float getBrothStrengthPotential() {
		return brothStrengthPotential;
	}

	@Override
	public float getVolume() {
		return volume;
	}
}

==> pogamut-emohawk-ville-3.5.4-20140114.043709-29-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/item/ingredient/AbstractSolidIngredientSliceMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.observationMemory.memorization.item.AbstractCountableItemMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.item.ingredient.AbstractSolidIngredientSliceReplica;

/** Abstract solid ingredient slice memorization
 */
public class AbstractSolidIngredientSliceMemorization
	<MemorizedClass extends AbstractSolidIngredientSliceReplica>
	extends AbstractCountableItemMemorization<MemorizedClass> 
	implements IBrothableIngredientMemorization<MemorizedClass>, ICharrableIngredientMemorization<MemorizedClass>, IBoilableIngredientMemorization<MemorizedClass> {
	
	protected float boiledness, charredness, brothStrengthPotential, volume;
	
	public AbstractSolidIngredientSliceMemorization(
		MemorizedClass object, 
		ObservationMemory observationMemory,
		IDeferredConstructorChainer deferredConstructorChainer
	) {
		super( object, observationMemory, deferredConstructorChainer );
		boiledness = object.getBoiledness();
		charredness = object.getCharredness();
		brothStrengthPotential = object.getBrothStrengthPotential();
		volume = object.getVolume();
	}

	@Override
	public float getBoiledness() {
		return boiledness;
	}
	
	@Override
	public float getCharredness() {
		return charredness;
	}

	@Override
	public float getBrothStrengthPotential() {
		return brothStrengthPotential;
	}

	@Override
	public float getVolume() {
		return volume;
	}
}
